#!/usr/bin/env bash

# This script is called by p1.test.user.bash
# It runs as atlascdr on the test host.

if [ x"$1" == x ]; then
  echo "usage: $0 {CastorScript config file}"
  exit 1
fi

cd `dirname $0`
SOURCE_DIR=`pwd`/..
REMOTE_DIR="/eos/atlas/atlastier0/daq/test/CastorScript.tests"
CS_CONFIG_FILE="$1"

echo "Cleaning remote EOS test area: $REMOTE_DIR"
KEYTAB_FILE="/daq_area/castor/`hostname -s`/atlascdr/atlascdr.keytab"
kinit -kt $KEYTAB_FILE atlascdr
for i in $(seq 0 9); do
	echo "Removing: dummy$i.data"
	xrdfs eosatlas rm /eos/atlas/atlastier0/daq/test/CastorScript.tests/dummy$i.data &> /dev/null
done

TMP_DIR=/tmp/atlascdr
echo "Cleaning tmp directory: $TMP_DIR"
rm -rf $TMP_DIR
mkdir -p $TMP_DIR/logs

echo "Creating dummy data files"
for i in `seq 0 9`; do
	dd if=/dev/zero of=$TMP_DIR/dummy$i.data bs=1k count=1
done

echo "Starting CastorScript with config file: $CS_CONFIG_FILE"
source $SOURCE_DIR/script_setup.sh
python -u $SOURCE_DIR/Script/CastorScript.py $CS_CONFIG_FILE &

# through ssh and su, TERM is not set and tput is lost
export TERM=xterm

echo "Watching files to transfer"
NF=`find $TMP_DIR -maxdepth 1 -name dummy* | wc -l`
for i in `seq 0 $NF`; do echo; done
for i in `seq 0 $NF`; do tput cuu1; done

while [ "0$NF" -gt 0 ] ; do
        LS_OUTPUT=`ls -l $TMP_DIR/dummy*`
        NL=`echo "$LS_OUTPUT" | wc -l`
        echo "$LS_OUTPUT"

        sleep 1

        for i in `seq 0 $NL`; do tput cuu1; done
        for i in `seq 0 $NL`; do
          echo "                                                                                "
        done
        for i in `seq 0 $((NL-1))`; do tput cuu1; done

        NF=`find $TMP_DIR -maxdepth 1 -name dummy* | wc -l`
done

echo "Stopping CastorScript"
~flegoff/castor_tools/signal-script.sh 12

echo "Cleaning remote files"
for i in $(seq 0 9); do
	echo "Removing: /eos/atlas/atlastier0/daq/test/CastorScript.tests/dummy$i.data"
	xrdfs eosatlas rm /eos/atlas/atlastier0/daq/test/CastorScript.tests/dummy$i.data
done

echo "Check logs at: $TMP_DIR/logs"
echo "Don't forget to: rm -rf $TMP_DIR"
