#!/usr/bin/env bash

if [ $# -lt 1 -o $# -gt 2 ]; then
  echo "usage: $0 [-no_cs_part] {test host}"
	exit 1
fi

cd `dirname $0`

CS_PARTITION="yes"
if [ $# -eq 2 ]; then
  CS_PARTITION="no"
  shift
fi
TESTHOST=$1

running_cs=`ssh $TESTHOST "ps -ef | grep CastorScript | grep -v -c grep"`

if [ "$running_cs" != "0" ]; then
	echo "error: there seems to be some CastorScript running on $TESTHOST"
	exit 2
else
	echo "OK: no running CastorScript instances on $TESTHOST"
fi

KEYTAB_FILE="/daq_area/castor/$TESTHOST/atlascdr/atlascdr.keytab"
if ! ssh $TESTHOST "sudo -u atlascdr -i cat $KEYTAB_FILE &>/dev/null"; then
	echo "error: keytab file not readble by atlascdr ($KEYTAB_FILE)"
	exit 3
else
	echo "OK: readable keytab file: $KEYTAB_FILE"
fi

if [ $CS_PARTITION = "yes" ]; then
  CS_CONFIG_FILE=test_config_is_ers.cfg
else
  CS_CONFIG_FILE=test_config.cfg
fi

if ! sed -r "s:/daq_area/castor/[a-zA-Z0-9-]+/atlascdr/atlascdr.keytab:/daq_area/castor/$TESTHOST/atlascdr/atlascdr.keytab:" $CS_CONFIG_FILE -i; then
	echo "error: cannot modify CastorScript config file: $CS_CONFIG_FILE"
	exit 4
else
	echo "OK: CastorScript config file modified: $CS_CONFIG_FILE "
fi

ssh $TESTHOST sudo -u atlascdr -i $PWD/p1.test.atlascdr.bash $PWD/$CS_CONFIG_FILE
