import unittest
#import mock
import os

if __name__ == '__main__':
    import sys
    from os.path import dirname, abspath, join
    # add CastorScript/Script to path so imports keeps working
    SCRIPT_DIR = abspath(join(dirname(__file__), '..'))
    sys.path.append(SCRIPT_DIR)

from cs.Tools.ConfigParser import ConfigHolder

class TestConfigHolder(unittest.TestCase):

    @classmethod
    def setUpClass(self):
        self.this_dir = os.path.dirname(__file__)
        self.template_config_name = "template.cfg"
        self.template_config_path = os.path.abspath(os.path.join(self.this_dir, "../../Configs/" + self.template_config_name))
        self.test_config_path = os.path.abspath(os.path.join(self.this_dir, "funcTestConf.cfg"))

    @classmethod
    def tearDownClass(self):
        os.remove(self.test_config_path)

    def test_it_should_save_config_file_name(self):
        config = ConfigHolder(self.template_config_path)
        self.assertEqual(self.template_config_name, config.FileName)

    def test_it_should_save_IS_parameters(self):
        custom_config_lines = {
            "IS_enabled: ": "IS_enabled: {}\n".format(True),
            "IS_partition: ": "IS_partition: \'{}\'\n".format("testPartition"),
            "IS_server: ": "IS_server: \'{}\'\n".format("testServer"),
            "IS_publication_period: ": "IS_publication_period: {}\n".format(200),
                }

        make_custom_config(self.template_config_path, self.test_config_path, custom_config_lines)

        config = ConfigHolder(self.test_config_path)
        self.assertEqual(True, config.IS_enabled)
        self.assertEqual("testPartition", config.IS_partition)
        self.assertEqual("testServer", config.IS_server)
        self.assertEqual(200, config.IS_publication_period)

    def test_it_should_save_IS_default_parameters_if_none_configured(self):
        custom_config_lines = {
            "IS_enabled: ": "\n",
            "IS_partition: ": "\n",
            "IS_server: ": "\n",
            "IS_publication_period: ": "\n",
                }

        make_custom_config(self.template_config_path, self.test_config_path, custom_config_lines)

        config = ConfigHolder(self.test_config_path)
        self.assertEqual(True, config.IS_enabled)
        self.assertEqual("initial", config.IS_partition)
        self.assertEqual("RunParams", config.IS_server)
        self.assertEqual(5, config.IS_publication_period)

def make_custom_config(original_conf_path, custom_conf_path, modifications):

    test_config_file = open(custom_conf_path, "w")
    template_config_file = open(original_conf_path, "r")

    # And I copy the content and add my own modifications
    for line in template_config_file:
        for key, value in modifications.items():
            if line.find(key) is not -1:
                line = value
        test_config_file.write(line)

    ## close files
    test_config_file.close()
    template_config_file.close()


if __name__ == '__main__':
    unittest.main()
